@@ -27,6 +27,9 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <gdk/gdkkeysyms.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
 
 #include "schemas.h"
 #include "preferences.h"
@@ -61,7 +64,7 @@ cb_change (GtkComboBox *widget,
 {
   gchar *device_name;
 
-  device_name = gtk_combo_box_get_active_text (widget);
+  device_name = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (widget));
   g_return_if_fail (device_name != NULL);
 
   g_settings_set_string (win->settings, MATE_VOLUME_CONTROL_KEY_ACTIVE_ELEMENT, device_name);
@@ -107,7 +110,7 @@ cb_help (GtkAction *action,
 
   screen = gtk_window_get_screen (GTK_WINDOW (win));
 
-  if (gtk_show_uri (screen, "ghelp:mate-volume-control", GDK_CURRENT_TIME,
+  if (gtk_show_uri (screen, "help:mate-volume-control", GDK_CURRENT_TIME,
   				&error) == FALSE) {
   	dialog = gtk_message_dialog_new (GTK_WINDOW (win), GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", error->message);
@@ -340,7 +343,7 @@ mate_volume_control_window_new (GList *elements)
   }
   active_element_num = count;
 
-  combo_box = gtk_combo_box_new_text ();
+  combo_box = gtk_combo_box_text_new ();
   renderer = gtk_cell_renderer_text_new ();
   g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
   gtk_cell_layout_clear (GTK_CELL_LAYOUT (combo_box));
@@ -350,7 +353,7 @@ mate_volume_control_window_new (GList *elements)
     const gchar *name;
 
     name = g_object_get_data (item->data, "mate-volume-control-name");
-    gtk_combo_box_append_text(GTK_COMBO_BOX (combo_box), name);
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (combo_box), name);
   }
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), active_element_num);
   g_signal_connect (combo_box, "changed", G_CALLBACK (cb_change), win);
