@@ -23,11 +23,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <math.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
 
 #include "gvc-channel-bar.h"
 #include "gvc-balance-bar.h"
@@ -64,6 +68,7 @@ struct GvcMixerDialogPrivate
         GtkWidget       *input_box;
         GtkWidget       *output_box;
         GtkWidget       *applications_box;
+        GtkWidget       *applications_scrolled_window;
         GtkWidget       *no_apps_label;
         GtkWidget       *output_treeview;
         GtkWidget       *output_settings_box;
@@ -1960,11 +1965,18 @@ gvc_mixer_dialog_constructor (GType                  type,
         gtk_container_add (GTK_CONTAINER (box), self->priv->output_settings_box);
 
         /* Applications */
+        self->priv->applications_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (self->priv->applications_scrolled_window),
+                                        GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (self->priv->applications_scrolled_window),
+                                             GTK_SHADOW_IN);
         self->priv->applications_box = gtk_vbox_new (FALSE, 12);
         gtk_container_set_border_width (GTK_CONTAINER (self->priv->applications_box), 12);
+        gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (self->priv->applications_scrolled_window),
+                                               self->priv->applications_box);
         label = gtk_label_new (_("Applications"));
         gtk_notebook_append_page (GTK_NOTEBOOK (self->priv->notebook),
-                                  self->priv->applications_box,
+                                  self->priv->applications_scrolled_window,
                                   label);
         self->priv->no_apps_label = gtk_label_new (_("No application is currently playing or recording audio."));
         gtk_box_pack_start (GTK_BOX (self->priv->applications_box),
@@ -2091,7 +2103,9 @@ gvc_mixer_dialog_new (GvcMixerControl *control)
         dialog = g_object_new (GVC_TYPE_MIXER_DIALOG,
                                "icon-name", "multimedia-volume-control",
                                "title", _("Sound Preferences"),
+#if !GTK_CHECK_VERSION (3, 0, 0)
                                "has-separator", FALSE,
+#endif
                                "mixer-control", control,
                                NULL);
         return GVC_MIXER_DIALOG (dialog);
