@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <math.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -37,6 +38,12 @@
 #include "gvc-channel-bar.h"
 #include "gvc-stream-status-icon.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-desktop-utils.h>
+#define gdk_spawn_command_line_on_screen mate_gdk_spawn_command_line_on_screen
+#endif
+
 #define GVC_STREAM_STATUS_ICON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GVC_TYPE_STREAM_STATUS_ICON, GvcStreamStatusIconPrivate))
 
 struct GvcStreamStatusIconPrivate
@@ -137,7 +144,11 @@ popup_dock (GvcStreamStatusIcon *icon,
 
         gtk_container_foreach (GTK_CONTAINER (icon->priv->dock), 
                                (GtkCallback) gtk_widget_show_all, NULL);
+#if GTK_CHECK_VERSION (3, 0, 0)
+        gtk_widget_get_preferred_size (icon->priv->dock, &dock_req, NULL);
+#else
         gtk_widget_size_request (icon->priv->dock, &dock_req);
+#endif
 
         if (orientation == GTK_ORIENTATION_VERTICAL) {
                 if (area.x + area.width + dock_req.width <= monitor.x + monitor.width) {
@@ -206,6 +217,22 @@ on_status_icon_activate (GtkStatusIcon       *status_icon,
         popup_dock (icon, GDK_CURRENT_TIME);
 }
 
+static gboolean
+on_status_icon_button_press (GtkStatusIcon       *status_icon,
+                             GdkEventButton      *event,
+                             GvcStreamStatusIcon *icon)
+{
+        /* middle click acts as mute/unmute */
+        if (event->button == 2) {
+                gboolean is_muted;
+                is_muted = gvc_mixer_stream_get_is_muted (icon->priv->mixer_stream);
+                gvc_mixer_stream_set_is_muted (icon->priv->mixer_stream, !is_muted);
+                gvc_mixer_stream_change_is_muted (icon->priv->mixer_stream, !is_muted);
+                return TRUE;
+        }
+        return FALSE;
+}
+
 static void
 on_menu_mute_toggled (GtkMenuItem         *item,
                       GvcStreamStatusIcon *icon)
@@ -779,6 +806,10 @@ gvc_stream_status_icon_init (GvcStreamStatusIcon *icon)
                           "activate",
                           G_CALLBACK (on_status_icon_activate),
                           icon);
+        g_signal_connect (icon,
+                          "button-press-event",
+                          G_CALLBACK (on_status_icon_button_press),
+                          icon);
         g_signal_connect (icon,
                           "popup-menu",
                           G_CALLBACK (on_status_icon_popup_menu),
