@@ -54,7 +54,11 @@ static void     gvc_sound_theme_chooser_class_init (GvcSoundThemeChooserClass *k
 static void     gvc_sound_theme_chooser_init       (GvcSoundThemeChooser      *sound_theme_chooser);
 static void     gvc_sound_theme_chooser_finalize   (GObject            *object);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+G_DEFINE_TYPE (GvcSoundThemeChooser, gvc_sound_theme_chooser, GTK_TYPE_BOX)
+#else
 G_DEFINE_TYPE (GvcSoundThemeChooser, gvc_sound_theme_chooser, GTK_TYPE_VBOX)
+#endif
 
 #define KEY_SOUNDS_SCHEMA          "org.mate.sound"
 #define EVENT_SOUNDS_KEY           "event-sounds"
